@@ -1,3 +1,4 @@
+import dataclasses
 import unittest
 from irisml.core.context import Context
 from irisml.core.variable import EnvironmentVariable, OutputVariable
@@ -37,3 +38,16 @@ class TestContext(unittest.TestCase):
 
         context.add_outputs('test_out', DummyOutput())
         self.assertEqual(context.resolve([123, OutputVariable('$output.test_out.value')]), [123, 3])
+
+    def test_resolve_nested_dataclass(self):
+        @dataclasses.dataclass
+        class ChildConfig:
+            value: int
+
+        @dataclasses.dataclass
+        class Config:
+            child: ChildConfig
+
+        config = Config(ChildConfig(42))
+        context = Context()
+        self.assertEqual(context.resolve(config), config)
